Part of `edX code`_.

.. _`edX code`: http://code.edx.org/

edx-user-state-client |Build Status| |Coverage Status|
======================================================

Python module for storing/querying user state in edx-platform. Contains interface which will handle
all backends for user states.

.. |Build Status| image:: https://travis-ci.com/edx/edx-user-state-client.svg?branch=master
   :target: https://travis-ci.com/edx/edx-user-state-client
.. |Coverage Status| image:: https://coveralls.io/repos/github/edx/edx-user-state-client/badge.svg?branch=master
   :target: https://coveralls.io/github/edx/edx-user-state-client?branch=master


How to Contribute
-----------------
Contributions are very welcome, but please note that edx-user-state-client is currently an early stage
work-in-progress and is changing frequently at this time.

See our `CONTRIBUTING`_ file for more information – it also contains guidelines for how to
maintain high code quality, which will make your contribution more likely to be accepted.

.. _CONTRIBUTING: https://github.com/edx/edx-platform/blob/master/CONTRIBUTING.rst


Reporting Security Issues
-------------------------
Please do not report security issues in public. Please email security@edx.org.


Mailing List and IRC Channel
----------------------------

You can discuss this code on the `edx-code Google Group`_ or in the
``edx-code`` IRC channel on Freenode.

.. _edx-code Google Group: https://groups.google.com/forum/#!forum/edx-code
